<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\MinhasTarefasService;

class MinhasTarefasController extends FMCrud
{
    protected $dataSourceName = 'fcm_checklistagend';
    protected $MinhasTarefasService;

    public function __construct($crudService, $environment, $MinhasTarefasService) {
        parent::__construct($crudService, $environment);
        $this->MinhasTarefasService = $MinhasTarefasService;
    }
    
    // -------> FUNÇÕES DA TELA LISTA DE TAREFAS <-------- //

    // Função para setar os valores do select de local
    public function getPlace(DTO\Request $request, DTO\Response $response) {

        $variavel = $this->MinhasTarefasService->getPlace();
        $dtsVal = new DataSet('place', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getSituation(DTO\Request $request, DTO\Response $response) {

        $variavel = $this->MinhasTarefasService->getSituation();
        $dtsVal = new DataSet('situation', $variavel);
        $response->addDataSet($dtsVal);
    }

    //Função para trazer os dados dos cards
    public function getTaskScheduled(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();
        
        $variavel = $this->MinhasTarefasService->getTaskScheduled($parametro['filter'], $parametro['usersIds']);
        $dtsVal = new DataSet('cardScheduled', $variavel);
        $response->addDataSet($dtsVal);
    }

    // Funções da Tela Minhas Tarefas
    public function nextTaskCard(DTO\Request $request, DTO\Response $response) {
        try {
            $parametro = $request->getParameters();
        
            $variavel = $this->MinhasTarefasService->nextTaskCard($parametro);
            $dtsVal = new DataSet('nextTC', $variavel);
            $response->addDataSet($dtsVal);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function changeStatusTask(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $this->MinhasTarefasService->changeStatusTask($parametro);

    }

    // Funções da Tela de Detalhamento
    public function getDetailsTask(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $variavel = $this->MinhasTarefasService->getDetailsTask($parametro);
        $dtsVal = new DataSet('cardDetails', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getItensDetailsTask(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $variavel = $this->MinhasTarefasService->getItensDetailsTask($parametro);
        $dtsVal = new DataSet('cardItensDetails', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function statusCheck(DTO\Request $request, DTO\Response $response) {
        $parametro = $request->getParameters();
        
        $variavel = $this->MinhasTarefasService->statusCheck($parametro);
        $dtsVal = new DataSet('statuschk', $variavel);
        $response->addDataSet($dtsVal);
    }
    
    public function getitensDetailsTaskForVistoria(DTO\Request $request, DTO\Response $response) {
        $response->addDataSet(new DataSet('details', $this->MinhasTarefasService->itensDetailsTaskForVistoria($request->getParameters())));
    }

    public function finishTaskDetails(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $variavel = $this->MinhasTarefasService->finishTaskDetails($parametro);
        $dtsVal = new DataSet('finishTask', [$variavel]);
        $response->addDataSet($dtsVal);
    }

    public function getDetailsTaskVistoria(DTO\Request $request, DTO\Response $response) {
        $response->addDataSet(new DataSet('details', $this->MinhasTarefasService->itensDetailsTaskForVistoria($request->getParameters())));
    }
}
?>